@@ -173,7 +173,7 @@ def detect_browser(method):
 
 def detect_ie(method):
     """
-    ie 7+
+    ie 678
     :return:
     """
 
@@ -185,6 +185,8 @@ def detect_ie(method):
             self.hacking_ie = 6
         elif user_agent.find("MSIE 7") > -1:
             self.hacking_ie = 7
+        elif user_agent.find("MSIE 8") > -1:
+            self.hacking_ie = 8
 
         return method(self, *args, **kwargs)
 
@@ -343,7 +345,7 @@ class RequestHandler(tornado.web.RequestHandler):
         return None
 
 
-    def post_redirect(self, url, msg, data, breads_title=[], breads_url=[], rec_title=[], rec_url=[], *args, **kwargs):
+    def post_redirect(self, url, msg, breads_title=[], breads_url=[], rec_title=[], rec_url=[], *args, **kwargs):
         """
         don't use get to set argument
         :param url:
